==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/build.sh <==
#!/usr/bin/env sh
set -e

die() {
  echo "$@"
  exit 1
}

fmt() {
  ag -g '.go$' | xargs -IC go fmt C
}

testall() {
  test
  testrealistic
}

testzipgtfs() {
  # E.g. tests based on actual GTFS zip archives from serveral sources
  # frozen/snappshotted; disabled by default since this is a relatively
  # heavyweight operation (e.g. importing 10s-100s of MB of GTFS data)
  #
  # Full tests take on order of minutes; results for these tests
  # are also generated into a viewable HTML page with perf stats etc.
  go test -timeout 30m -p 1 -v -tags=sqlite_math_functions,zipgtfs -buildvcs=false api/apiroute_test/apiroute_zipgtfs_test.go
}

test() {
  if [ -n "$1" ]; then
    go test -failfast -p 1 -v -tags=sqlite_math_functions -buildvcs=false "$1"
  else
    go test -failfast -p 1 -v -tags=sqlite_math_functions -buildvcs=false ./...
  fi
}

updatemobsql() {
  GOPROXY=direct go get -v -u git.sr.ht/~mil/mobsql@master
}

um() {
  updatemobsql
}

pp() {
  USER=user
  CONN=$USER@pine64-pinephone
  rsync --delete -v -a . $CONN:/home/$USER/mobroute
  ssh -t $CONN 'sudo sh -c "
    set -e
    cd /home/'$USER'/mobroute
    ./build.sh install
  "'
}

build() {
  go build -o mobroute -tags=sqlite_math_functions -buildvcs=false cli/mobroutecli.go
}

run() {
  build
  ./mobroute "$@"
}

install() {
  [ $(whoami) = "root" ] || die "Must run as root"
  build
  cp $BINARY /usr/local/bin/
  echo "Installed $BINARY to /usr/local/bin ok"

  cp scripts/* /usr/local/bin
  echo "Installed scripts to /usr/local/bin ok"
}

if [ -z "$1" ]; then
  build
else
  "$@"
fi

==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/build.sh <==
#!/usr/bin/env sh
set -e

die() {
  echo "$@"
  exit 1
}

fmt() {
  ag -g '.go$' | xargs -IC go fmt C
}

testall() {
  test
  testzipgtfs
}

testzipgtfs() {
  # E.g. tests based on actual GTFS zip archives from serveral sources
  # frozen/snappshotted; disabled by default since this is a relatively
  # heavyweight operation (e.g. importing 10s-100s of MB of GTFS data)
  #
  # Full tests take on order of minutes; results for these tests
  # are also generated into a viewable HTML page with perf stats etc.
  go test -timeout 30m -p 1 -v -tags=sqlite_math_functions,zipgtfs -buildvcs=false api/apioneshot_test/apioneshot_zipgtfs_test.go
}

test() {
  if [ -n "$1" ]; then
    go test -failfast -p 1 -v -tags=sqlite_math_functions -buildvcs=false "$1"
  else
    go test -failfast -p 1 -v -tags=sqlite_math_functions -buildvcs=false ./...
  fi
}

updatemobsql() {
  GOPROXY=direct go get -v -u git.sr.ht/~mil/mobsql@master
}

um() {
  updatemobsql
}

pp() {
  USER=user
  CONN=$USER@pine64-pinephone
  rsync --delete -v -a . $CONN:/home/$USER/mobroute
  ssh -t $CONN 'sudo sh -c "
    set -e
    cd /home/'$USER'/mobroute
    ./build.sh install
  "'
}

build() {
  go build -o mobroute -tags=sqlite_math_functions -buildvcs=false cli/*
}

run() {
  build
  ./mobroute "$@"
}

install() {
  [ $(whoami) = "root" ] || die "Must run as root"
  build
  cp $BINARY /usr/local/bin/
  echo "Installed $BINARY to /usr/local/bin ok"

  cp scripts/* /usr/local/bin
  echo "Installed scripts to /usr/local/bin ok"
}

if [ -z "$1" ]; then
  build
else
  "$@"
fi
